PrivilegeDialog class

Constructors

PrivilegeDialog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

successOrCancel({required BuildContext context, String? title, String? content, String? confirm, String? cancel, bool? barrierDismissible, dynamic onConfirm()?, dynamic onCancel()?}) Future